##  Accessing the AI Agent Discovery Inbox
To open the inbox, do the following:
  1. Go to the Inventory.
  2. Go to Inventory Tools > Discovery Inbox  > AI Agent Discovery.


**Note**
Only users with admin rights can access the AI agent inbox. However, admins can grant access to other roles by configuring permissions in the administration area. For more details, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
Granting permission to non-admin roles is useful when discovered items need to be reviewed by subject-matter experts.
